var _ogre_shader_ex_per_pixel_lighting_8h =
[
    [ "SGX_LIB_PERPIXELLIGHTING", "group___r_t_shader.html#ga62fd9d3400be2887116459919fa3d3aa", null ],
    [ "SGX_FUNC_LIGHT_DIRECTIONAL_DIFFUSE", "group___r_t_shader.html#ga75eb5ea0eac488234a8749b8a86ae918", null ],
    [ "SGX_FUNC_LIGHT_DIRECTIONAL_DIFFUSESPECULAR", "group___r_t_shader.html#gae56f940b43f696b1d9c90a5d419903d8", null ],
    [ "SGX_FUNC_LIGHT_POINT_DIFFUSE", "group___r_t_shader.html#ga783580599433f492381773aff51b3e66", null ],
    [ "SGX_FUNC_LIGHT_POINT_DIFFUSESPECULAR", "group___r_t_shader.html#ga109d92eb58c1e1d0ce7e1248f79d7e14", null ],
    [ "SGX_FUNC_LIGHT_SPOT_DIFFUSE", "group___r_t_shader.html#ga2620bcaeb32a88f06ae1f3c8cecbb1e6", null ],
    [ "SGX_FUNC_LIGHT_SPOT_DIFFUSESPECULAR", "group___r_t_shader.html#ga8f20b2f1284e114cd7b098e4ad5e418b", null ]
];